==> mongodb-6.0.22.gh.tar.gz: mongo-r6.0.22/src/mongo/db/index/expression_params.h <==
/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include <string>
#include <vector>

#include "mongo/db/hasher.h"
#include "mongo/db/jsobj.h"

namespace mongo {

class CollatorInterface;
struct TwoDIndexingParams;
struct S2IndexingParams;

namespace ExpressionParams {

void parseTwoDParams(const BSONObj& infoObj, TwoDIndexingParams* out);

void parseHashParams(const BSONObj& infoObj,
                     HashSeed* seedOut,
                     int* versionOut,
                     BSONObj* keyPattern);

void parseHaystackParams(const BSONObj& infoObj,
                         std::string* geoFieldOut,
                         std::vector<std::string>* otherFieldsOut,
                         double* bucketSizeOut);

void initialize2dsphereParams(const BSONObj& infoObj,
                              const CollatorInterface* collator,
                              S2IndexingParams* out);

}  // namespace ExpressionParams

}  // namespace mongo

==> mongodb-8.0.8.gh.tar.gz: mongo-r8.0.8/src/mongo/db/index/expression_params.h <==
/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include <string>
#include <vector>

#include "mongo/bson/bsonobj.h"
#include "mongo/db/hasher.h"
#include "mongo/db/jsobj.h"

namespace mongo {

class CollatorInterface;
struct TwoDIndexingParams;
struct S2IndexingParams;

namespace ExpressionParams {

void parseTwoDParams(const BSONObj& infoObj, TwoDIndexingParams* out);

void parseHashParams(const BSONObj& infoObj, int* versionOut, BSONObj* keyPattern);

void parseHaystackParams(const BSONObj& infoObj,
                         std::string* geoFieldOut,
                         std::vector<std::string>* otherFieldsOut,
                         double* bucketSizeOut);

void initialize2dsphereParams(const BSONObj& infoObj,
                              const CollatorInterface* collator,
                              S2IndexingParams* out);

}  // namespace ExpressionParams

}  // namespace mongo
